summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pminsertpopup.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
commite69e8b1d09fb579316595b4e6a850e717358a8b1 (patch)
treea24fc20865f65772f530d16177520190594ffdd2 /kpovmodeler/pminsertpopup.h
parenteecec9afb81fdebb0f22e9da22635874c403f854 (diff)
downloadtdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.tar.gz
tdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.zip
TQt4 port kdegraphics
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1237557 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpovmodeler/pminsertpopup.h')
-rw-r--r--kpovmodeler/pminsertpopup.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kpovmodeler/pminsertpopup.h b/kpovmodeler/pminsertpopup.h
index 09aa796a..3ec3ecd3 100644
--- a/kpovmodeler/pminsertpopup.h
+++ b/kpovmodeler/pminsertpopup.h
@@ -39,13 +39,13 @@ public:
/**
* Creates a popup menu
*
* @param parent The parent widget
* @param multipleObjects True if more than one object will be inserted
* @param items Which items to display. Can be a bitwise combination
* of PMIFirstChild, PMILastChild, PMISibling.
* @param name Internal name of the popup menu
*/
- PMInsertPopup( TQWidget* parent, bool multipleObjects,
+ PMInsertPopup( TQWidget* tqparent, bool multipleObjects,
int items = PMIFirstChild | PMILastChild | PMISibling,
bool canInsertAllAsFirstChildren = true,
bool canInsertAllAsLastChildren = true,
@@ -59,7 +59,7 @@ public:
/**
* Popups a PMInsertPopup menu
*
* @param parent The parent widget
* @param multipleObjects True if more than one object will be inserted
* @param items Which items to display. Can be a bitwise combination
* of PMIFirstChild, PMILastChild, PMISibling.
@@ -70,7 +70,7 @@ public:
*
* Returns the selected item or 0 if no item was selected.
*/
- static int choosePlace( TQWidget* parent, bool multipleObjects,
+ static int choosePlace( TQWidget* tqparent, bool multipleObjects,
int items = PMIFirstChild | PMILastChild
| PMISibling,
bool canInsertAllAsFirstChildren = true,
@@ -39,13 +39,13 @@ public:
* Creates a popup menu
*
- * @param parent The parent widget
+ * @param tqparent The tqparent widget
* @param multipleObjects True if more than one object will be inserted
* @param items Which items to display. Can be a bitwise combination
@@ -59,7 +59,7 @@ public:
* Popups a PMInsertPopup menu
*
- * @param parent The parent widget
+ * @param tqparent The tqparent widget
* @param multipleObjects True if more than one object will be inserted
* @param items Which items to display. Can be a bitwise combination